################################################################################
# httpd.conf -- Configuration file for apache.
# Customized for use with EnGarde Linux and the AllCommerce package.
#
# Ryan W. Maple <ryan@guardiandigital.com>
# December 2, 2000
################################################################################

################################################################################
# Server Defaults ##############################################################
################################################################################

### This should always be 'standalone'.
ServerType standalone

### The 'root' of the server (config, modules, etc).
ServerRoot "/etc/httpd"

### The lock file used by the process.
LockFile /var/lock/httpd.lock

### The file that holds the PID of the master process.
PidFile /var/run/httpd.pid

###  The amount of time Apache will wait for some operations (GET, POST, etc).
Timeout 300

### Allow multiple requests to be sent over the same TCP connection.
KeepAlive On

### Basic performance tuning.  Read the apache manual for information.
MaxKeepAliveRequests 100
KeepAliveTimeout 15
MinSpareServers 5
MaxSpareServers 20
StartServers 5
MaxClients 150
MaxRequestsPerChild 100

### Default port, user, and group the daemon runs to/listens on.
Port 80
User webd
Group webd

### Ports to listen on.
Listen 80
Listen 443

### Generate self-referenced URLs.
UseCanonicalName On

### Disable DNS lookups.
HostnameLookups Off

### Default 'Content-type:' used when an unknown is encountered.
DefaultType text/plain

### Only send product information, not version or host information.
ServerTokens Prod



################################################################################
# Load Modules #################################################################
################################################################################
LoadModule vhost_alias_module modules/mod_vhost_alias.so
LoadModule env_module         modules/mod_env.so
LoadModule config_log_module  modules/mod_log_config.so
LoadModule agent_log_module   modules/mod_log_agent.so
LoadModule referer_log_module modules/mod_log_referer.so
LoadModule mime_module        modules/mod_mime.so
LoadModule negotiation_module modules/mod_negotiation.so
LoadModule status_module      modules/mod_status.so
LoadModule info_module        modules/mod_info.so
LoadModule includes_module    modules/mod_include.so
LoadModule autoindex_module   modules/mod_autoindex.so
LoadModule dir_module         modules/mod_dir.so
LoadModule cgi_module         modules/mod_cgi.so
LoadModule asis_module        modules/mod_asis.so
LoadModule imap_module        modules/mod_imap.so
LoadModule action_module      modules/mod_actions.so
LoadModule userdir_module     modules/mod_userdir.so
LoadModule alias_module       modules/mod_alias.so
LoadModule access_module      modules/mod_access.so
LoadModule expires_module     modules/mod_expires.so
LoadModule headers_module     modules/mod_headers.so
LoadModule setenvif_module    modules/mod_setenvif.so
LoadModule ssl_module         modules/libssl.so
LoadModule auth_module        modules/mod_auth.so
#LoadModule php4_module        modules/libphp4.so



################################################################################
# Add Modules ##################################################################
################################################################################
ClearModuleList

AddModule mod_vhost_alias.c
AddModule mod_env.c
AddModule mod_log_config.c
AddModule mod_log_agent.c
AddModule mod_log_referer.c
AddModule mod_mime.c
AddModule mod_negotiation.c
AddModule mod_status.c
AddModule mod_info.c
AddModule mod_include.c
AddModule mod_autoindex.c
AddModule mod_dir.c
AddModule mod_cgi.c
AddModule mod_asis.c
AddModule mod_imap.c
AddModule mod_actions.c
AddModule mod_userdir.c
AddModule mod_alias.c
AddModule mod_access.c
AddModule mod_expires.c
AddModule mod_headers.c
AddModule mod_so.c
AddModule mod_setenvif.c
AddModule mod_ssl.c
AddModule mod_auth.c
#AddModule mod_php4.c





################################################################################
# CGI, PHP, SSI, and Indexes ###################################################
################################################################################

  ##############################################################################
  ### We do not want CGIs to be ran by default, but we override this global
  ### definition in the individual VirtualHost directives.  We need the 
  ### AddHandler directives for those, but we set '-ExecCGI' globally.
  ###
  ### We apply this same logic for SSI.  If we want them, then set them in the
  ### VirtualHost directive.  Otherwise do not allow them.
  ###
  ### And, finally, the same goes for directory indexes.
  ###
  ### We leave the PHP defines commented and they're uncommented when PHP is
  ### installed.
  ##############################################################################

### Setup handlers for appropriate suffixes.
AddType text/html .shtml
AddHandler server-parsed .shtml
AddHandler cgi-script .cgi
AddHandler cgi-script .pl

### Do the Options thing. :)
Options -ExecCGI -Includes -Indexes

### For PHP, a .php page will go through PHP4.  Only .php3 is parsed by PHP3.
#AddType application/x-httpd-php3 .php3
#AddType application/x-httpd-php .php4
#AddType application/x-httpd-php .php

### Understand Proxy Autoconfiguration files (PAC's)
AddType application/x-ns-proxy-autoconfig .pac


################################################################################
# Default Server ###############################################################
################################################################################

  ##############################################################################
  ### Because the primary function of this box is to be a "network appliance",
  ### we will not want a "default server" in most cases as it is not
  ### configurable via the WebTool.  So to solve this problem we leave a blank
  ### white page for anybody who goes directly to the IP address or the
  ### "hostname" of this machine.
  ###
  ### You can still get to http://fqdn/~user, but make sure the permissions on
  ### /home/<user> are 0711 or greater. :)
  ##############################################################################

### Root for all 'default' connections.  Basically a white page.
DocumentRoot "/home/httpd/html"

### Define filenames for directory 'indexes' for 'default' connections.
DirectoryIndex index.html index.htm
UserDir public_html

### Define what file is used for per-dirctory access control.  See manual.
AccessFileName .htaccess

### By default, do NOT allow anybody to view our .htaccess or .htpasswd files.
<Files ~ "^\.ht">
    Order allow,deny
    Deny from all
</Files>

### File that holds type definitions.
TypesConfig /etc/mime.types



################################################################################
# Logging Directives ###########################################################
################################################################################
ErrorLog /var/log/httpd/error_log
LogLevel warn
LogFormat "%h %l %u %t \"%r\" %>s %b" common
LogFormat "%{Referer}i -> %U" referer
LogFormat "%{User-agent}i" agent
CustomLog /var/log/httpd/access_log common
ServerSignature Off



################################################################################
# Various Legacy Stuff... should be taken out eventually? ######################
################################################################################
IndexIgnore .??* *~ *# HEADER* README* RCS CVS *,v *,t

BrowserMatch "Mozilla/2" nokeepalive
BrowserMatch "MSIE 4\.0b2;" nokeepalive downgrade-1.0 force-response-1.0
BrowserMatch "RealPlayer 4\.0" force-response-1.0
BrowserMatch "Java/1\.0" force-response-1.0
BrowserMatch "JDK/1\.0" force-response-1.0



################################################################################
# SSL Directives ###############################################################
################################################################################
AddType application/x-x509-ca-cert .crt
AddType application/x-pkcs7-crl	   .crl

<IfModule mod_ssl.c>
  SSLPassPhraseDialog		builtin
  SSLSessionCache		dbm:/var/log/httpd/ssl_scache
  SSLSessionCacheTimeout	300
  SSLMutex			sem
  SSLRandomSeed			startup builtin
  SSLRandomSeed			connect builtin
  SSLLog			/var/log/httpd/ssl_engine_log
  SSLLogLevel			warn

  SetEnvIf User-Agent ".*MSIE.*" nokeepalive ssl-unclean-shutdown \
	downgrade-1.0 force-response-1.0
</IfModule>



################################################################################
# Begin Virtual Host Section ###################################################
################################################################################

### NameVirtualHost Directives

### VirtualHost Directives

